@@ -1,4 +1,4 @@
-/* Copyright (C) 2022 Free Software Foundation
+/* Copyright (C) 2022-2024 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -47,8 +47,6 @@ public final class Analyzer {
 
   // Runtime environment
   public static final String PERFORMANCE_ANALYZER_RELEASE_NAME = "gprofng GUI";
-  public static final String THIS_VERSION = "12.6";
-
   public static final String jvm_ver = System.getProperty("java.version", "unknown");
   public static final String jvm_home = System.getProperty("java.home", "unknown");
   public static final String home_dir =
@@ -64,8 +62,8 @@ public final class Analyzer {
   public boolean normalSelection = false; // Right click changes selection
   public boolean IPC_started = false;
   public boolean connectingToRemoteHost = false; // true during the connecting process
-  //    public int kernelProfilingEnabled = 0; // 0 - not initialized, 1 - "er_kernel" is available,
-  // 2 - not available
+  public boolean connectingToRemoteHostEnabled = false;
+  public boolean profileRunningProcessEnabled = false;
   public Boolean kernelProfilingEnabled = null;
   public boolean old_IPC_status = false;
   public int cur_id = 0;
@@ -398,8 +396,6 @@ public final class Analyzer {
         }
       }
     }
-    System.err.println("fdhome: " + (fdhome == null ? "" : fdhome));
-    System.err.println("gp-display-text: " + er_print);
     AnLog.log("analyzer: gp-display-text=" + er_print + "\n");
     // Check the OS - only Solaris and Linux are supported
     if (remoteHost == null) {
@@ -1833,8 +1829,8 @@ public final class Analyzer {
    */
   private String initIPC() throws Exception {
     AnUtility.checkIPCOnWrongThread(false);
-    String temporaryRemoteVersion = getAnalyzerReleaseName() + " " + THIS_VERSION;
-    fdversion = temporaryRemoteVersion;
+    String temporaryRemoteVersion = getAnalyzerReleaseName();
+    fdversion = "";
     String emsg = null;
     startIPC();
     // Version Handshake
